- n
The number of observations in the sequence; it must be at least 6.
- E
The edge matrix (a "number of edges" by 2 matrix) for the similarity graph. Each row contains the node indices of an edge.
- statistics
The scan statistics to be computed. The default is "m", which reports the max-type scan.
"all": specifies to compute all of the scan statistics: original, weighted, generalized, and max-type;
"o", "ori" or "original": specifies the original edge-count scan statistic;
"w" or "weighted": specifies the weighted edge-count scan statistic;
"g" or "generalized": specifies the generalized edge-count scan statistic; and
"m" or "max": specifies the max-type edge-count scan statistic.
- l0
The minimum length of the interval to be considered as a changed interval.
- l1
The maximum length of the interval to be considered as a changed interval.
- pval.appr
If it is TRUE, the function outputs a p-value approximation based on asymptotic properties. The analytic approximation requires n >= 9.
- skew.corr
This argument is useful only when pval.appr=TRUE. If skew.corr is TRUE, the p-value approximation would incorporate skewness correction.
- pval.perm
If it is TRUE, the function outputs p-value from doing B permutations, where B is another argument that you can specify. Doing permutation could be time consuming, so use this argument with caution as it may take a long time to finish the permutation.
- B
This argument is useful only when pval.perm=TRUE. The default value for B is 100.